@@ -14,12 +14,11 @@
 #  See the License for the specific language governing permissions and
 #  limitations under the License.
 
-from __future__ import absolute_import
 import re
-from calculate.lib.cl_xml import xpath
+from ..cl_xml import xpath
 from .generic import objShare
-from calculate.lib.cl_template import blocText
-from calculate.lib.cl_xml import xmlDoc
+from ..cl_template import blocText
+from ..cl_xml import xmlDoc, insertBefore
 
 
 class samba(objShare):
@@ -54,8 +53,8 @@ class samba(objShare):
             if not xmlFields:
                 removeList.append(xmlArea)
         for xmlArea in removeList:
-            parentNode = xmlArea.parentNode
-            parentNode.removeChild(xmlArea)
+            parentNode = xmlArea.getparent()
+            parentNode.remove(xmlArea)
 
         # Для добавления перевода строки между областями если его нет
         xmlAreas = xpath.Evaluate("child::area", self.docObj.body)
@@ -65,20 +64,20 @@ class samba(objShare):
             if not (xmlFields and (
                 self.docObj.getTypeField(xmlFields[-1]) == "br" or
                     self.docObj.getTypeField(xmlFields[-1]) == "comment")):
-                if xmlArea.nextSibling:
-                    parentNode = xmlArea.parentNode
-                    nextNode = xmlArea.nextSibling
-                    parentNode.insertBefore(self.docObj.createField(
+                if xmlArea.getnext() is not None:
+                    parentNode = xmlArea.getparent()
+                    nextNode = xmlArea.getnext()
+                    insertBefore(parentNode, self.docObj.createField(
                         "br", [], "", [], False, False), nextNode)
             # Добавление переводов строк между полями
             if xmlFields:
                 for node in xmlFields:
                     # Добавление перевода строк в если его нет между полями
                     if (self.docObj.getTypeField(node) == "var" and
-                            node.previousSibling and
+                            node.getprevious() is not None and
                             not (self.docObj.getTypeField(
-                                node.previousSibling) in ("br", "comment"))):
-                        xmlArea.insertBefore(self.docObj.createField(
+                                node.getprevious()) in ("br", "comment"))):
+                        insertBefore(xmlArea, self.docObj.createField(
                             "br", [], "", [], False, False), node)
 
         # Удаление лишних переводов строк
@@ -86,7 +85,7 @@ class samba(objShare):
         lenBr = 0
         removeBrNodes = []
         for node in childNodes:
-            if (node.tagName == "field" and
+            if (node.tag == "field" and
                     self.docObj.getTypeField(node) == "br"):
                 lenBr += 1
                 if lenBr > 2:
@@ -95,15 +94,15 @@ class samba(objShare):
                 lenBr = 0
         # Удаление
         for rmNode in removeBrNodes:
-            self.docObj.body.removeChild(rmNode)
+            self.docObj.body.remove(rmNode)
 
         # Если после есть BR а за ним ничего нет, удаляем BR
-        if xmlArea:
-            if (xmlArea.nextSibling and
-                    self.docObj.getTypeField(xmlArea.nextSibling) == "br"):
-                if not xmlArea.nextSibling.nextSibling:
-                    parentNode = xmlArea.nextSibling.parentNode
-                    parentNode.removeChild(xmlArea.nextSibling)
+        if xmlArea is not None:
+            if (xmlArea.getnext() is not None and
+                    self.docObj.getTypeField(xmlArea.getnext()) == "br"):
+                if xmlArea.getnext().getnext() is None:
+                    parentNode = xmlArea.getnext().getparent()
+                    parentNode.remove(xmlArea.getnext())
 
     def join(self, sambaObj):
         """Объединяем конфигурации"""
@@ -290,11 +289,11 @@ class samba(objShare):
                 area = docObj.createArea()
                 if areaAction:
                     docObj.setActionArea(area, areaAction)
-                rootNode.appendChild(area)
+                rootNode.append(area)
             else:
                 fieldsNodes = docObj.tmpFields.getFields()
                 for fieldNode in fieldsNodes:
-                    rootNode.appendChild(fieldNode)
+                    rootNode.append(fieldNode)
                 docObj.clearTmpFields()
             z += 1
         return docObj
